@@ -40,6 +40,14 @@ def sha256d(x: Union[bytes, str]) -> bytes:
     out = bytes(sha256(sha256(x)))
     return out
 
+def hash_160(x: bytes) -> bytes:
+    return ripemd(sha256(x))
+
+def ripemd(x: bytes) -> bytes:
+    md = hashlib.new('ripemd160')
+    md.update(x)
+    return md.digest()
+
 def assert_bytes(*args):
     """
     porting helper, assert args type
@@ -81,3 +89,40 @@ def msg_magic(message: bytes, altcoin=None) -> bytes:
         message_full= length_prefix + message_prefix + length + message
         return message_full
 
+__b58chars = b'123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz'
+
+def EncodeBase58Check(vchIn: bytes) -> str:
+    hash = sha256d(vchIn)
+    return base_encode(vchIn + hash[0:4], base=58)
+
+def base_encode(v: bytes, *, base: int) -> str:
+    """ encode v, which is a string of bytes, to base58."""
+    assert_bytes(v)
+    if base not in (58, 43):
+        raise ValueError('not supported base: {}'.format(base))
+    chars = __b58chars
+    if base == 43:
+        chars = __b43chars
+    long_value = 0
+    power_of_base = 1
+    for c in v[::-1]:
+        # naive but slow variant:   long_value += (256**i) * c
+        long_value += power_of_base * c
+        power_of_base <<= 8
+    result = bytearray()
+    while long_value >= base:
+        div, mod = divmod(long_value, base)
+        result.append(chars[mod])
+        long_value = div
+    result.append(chars[long_value])
+    # Bitcoin does a little leading-zero-compression:
+    # leading 0-bytes in the input become leading-1s
+    nPad = 0
+    for c in v:
+        if c == 0x00:
+            nPad += 1
+        else:
+            break
+    result.extend([chars[0]] * nPad)
+    result.reverse()
+    return result.decode('ascii')
\ No newline at end of file
